@@ -6,7 +6,7 @@
  *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
- * Copyright (c) 2000-2004.2007,2013 Kenneth J. Pronovici.
+ * Copyright (c) 2000-2004.2007,2013,2014 Kenneth J. Pronovici.
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -126,6 +126,9 @@
    #include <string.h>
 #endif
 
+#include <termios.h>
+#include <sys/ioctl.h>
+
 #include "letters.h"
 
 
@@ -567,12 +570,14 @@ static void usage(char *program)
           "AIX in the late 1990s.  It prints a short string to the console in very large\n"
           "letters.\n"
           "\n"
-          "If $COLUMNS is exported in the environment, it is taken to be the width of the\n"
-          "terminal. Otherwise, a terminal width of %d characters is assumed, and banners\n"
-          "that do not fit will be truncated.\n"
+          "Banners that do not fit in the terminal will be truncated.  If $COLUMNS is\n"
+          "exported in the environment, it is taken to be the width of the terminal.  If\n"
+          "$COLUMNS is not exported, and TIOCGWINSZ is available on the platform, then its\n"
+          "idea of the terminal size is used.  Otherwise, a terminal width of %d\n"
+          "characters is assumed.\n"
           "\n"
           "This is %s %s.\n"
-          "$LastChangedDate: 2013-04-02 21:20:18 -0500 (Tue, 02 Apr 2013) $.\n"
+          "$LastChangedDate: 2014-09-29 16:24:25 +0000 (Mon, 29 Sep 2014) $.\n"
           "Copyright (c) %s %s <%s>.\n"
           "\n"
           "Distributed under the GNU General Public License.\n"
@@ -660,6 +665,13 @@ int main(int argc, char *argv[])
    columns = getenv("COLUMNS");
    if(columns == NULL)
    {
+#ifdef TIOCGWINSZ
+      struct winsize ws;
+      ws.ws_col = 0;
+      if (!ioctl(1, TIOCGWINSZ, &ws) && ws.ws_col > 0)
+	      printwidth = ws.ws_col;
+      else
+#endif
       printwidth = DEFAULT_PRINTWIDTH;
    }
    else
